// A specific-use script component used by the Door entity to teleport other
// entities that explicitly activate the Door.
//
// Entity Attribute    Type    Description
// ----------------    ----    -----------
// destination         id      Destination entity to be teleported to.
//
{

script: {
    member OnConnect(args : map)
        // the destination entity is stored in the entity's attributes
        // so the doorway doesn't have to be reconnected if it is respawned
        // during a world file version upgrade.
        this.entity.destination := args.eid;
        this.entity.connections := [this.entity.destination];       // for the editor's benefit
    end function

    member OnDisconnect(args : map)
        if args.eid = this.entity.destination then
            this.entity.destination := null;
            this.entity.connections -= [args.eid];
        end if;
    end function

    // sends a Teleport command to the activating entity, instructing it
    // to begin teleporting to the location of the doorway's connected entity.
    member OnActivateAtWill(args : map)
        constant destination := this.entity.destination;            // destination entity
        if destination.Exists then
            args.eid.Send("Teleport", {
                fromX: this.entity.x
                fromY: this.entity.y - 16
                toX:   destination.x
                toY:   destination.y
            });
        end if;
    end function
}

}