// A specific-use script component used by the Emitter entity to manage an
// Emitter component attached to it. The Emitter's name, map layer, emission
// rate, and emission angle can all be configured though entity attributes.
//
// Entity Attribute    Type      Description
// ----------------    ----      -----------
// enabled             boolean
// emitterName         string
// emitLayer           number
// emitAngle           number
// emitRate            number
//
{

script: {
    emitter: null

    member OnSpawned() this.UpdateEmitter(); end function

    member OnAttributeChanged(attr : map) this.UpdateEmitter(); end function

    member OnSwitched() this.entity.enabled := !this.entity.enabled; end function

    member UpdateEmitter()
        if this.emitter != null then
            this.entity.RemoveComponent(this.emitter);
            this.emitter := null;
        end if;
        if this.entity.enabled and length(this.entity.emitterName) > 0 then
            this.emitter :=
                this.entity.AddComponent(
                    "Emitter",
                    {
                        emitter: {name: this.entity.emitterName, angle: this.entity.emitAngle}
                        x: 0, y: 0
                        layer: this.entity.emitLayer
                        rate: this.entity.emitRate
                        attached: true
                    }
                );
        end if;
    end function
}

}