{

script: {
    dir: -1

    // To mimic the jerky motion of the original inchworm, no velocity component
    // is used. The worm is run by timers that transition it between states.
    // Worms that are sufficiently far from the player do not update, to prevent
    // all the worms from congregating at the player from all over the level.
    //
    // There are slight variations in the timing and movement speed of the worms
    // from frame to frame. This is to prevent them from all acting exactly the
    // same when they're under foot.

    // todo:
    // [ ] worm needs to initially follow the player

    member active()
        return !game.editor and
            abs(world.player.x - this.entity.x) <= 240 and
            abs(world.player.y - this.entity.y) <= 240;
    end function

    member delayTime()
        return 450 + random() * 100;
    end function

    member Walk1()
        constant SPEED := 12 + random() * 2;           // distance per step
        if this.active() then
            if (this.dir < 0 and (this.entity.isBlockedLeft or !IsFloor(this.entity.left, this.entity.bottom + 1))) or
               (this.dir > 0 and (this.entity.isBlockedRight or !IsFloor(this.entity.right, this.entity.bottom + 1)))
            then
                // turn around when running into a wall or a ledge
                this.dir := -this.dir;
            end if;

            this.entity.x += this.dir * SPEED;
            this.entity.y += 6;                             // helps sticking down to slopes
            this.entity.frame := "inchworm_" & (this.dir < 0 ? "left" : "right") & "1";
        end if;
        this.SetTimer("Walk2", this.delayTime());
    end function

    member Walk2()
        if this.active() then
            // move backward slightly, as he scrunches up
            this.entity.x -= this.dir * 4;
            this.entity.y += 2;                             // helps sticking down to slopes
            this.entity.frame := "inchworm_" & (this.dir < 0 ? "left" : "right") & "2";
        end if;
        this.SetTimer("Walk1", this.delayTime());
    end function

    // periodically search for the player again
    member Follow()
        if this.active() then
            this.dir := (world.player.x < this.entity.x ? -1 : 1);
        end if;
    end function
}

// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - //

timers: {
    Follow: {time: 1000, repeat: true}             // keep following the player
    Walk1: 100
}

}
