// A specific-use script used by the Lift entity. A Lift always travels to its
// next path point, if it has one. When it arrives at the path point, it
// announces its arrival with "LiftArrived" message and then waits for a
// "LiftGoto" message that will tell it where to go next.
//
{

script: {
    member liftSpeed() return 47.65; end function         // pixels/sec

    member OnConnect(args : map)
        if args.eid.template = "LiftPath" then
            // the next path point is stored in the entity's attributes
            // so the path doesn't have to be reconnected if it is respawned
            // during a world file version upgrade.
            this.entity.nextPath := args.eid;
            this.entity.connections := [this.entity.nextPath];      // for the editor's benefit
        end if;
    end function

    member OnDisconnect(args : map)
        if args.eid = this.entity.nextPath then
            this.entity.nextPath := null;
            this.entity.connections -= [args.eid];
        end if;
    end function

    member OnLiftGoto(args : map)
        this.entity.nextPath := args.path;
        this.entity.connections := [this.entity.nextPath];          // for the editor's benefit
        this.nextPath();
    end function

    member OnPlayStarted()
        this.nextPath();
    end function

    member nextPath()
        local distX;
        local distY;
        local flightTime;

        if this.entity.nextPath = null or (this.entity.vx != 0 or this.entity.vy != 0) then
            // no next path point, or busy travelling
            return;
        end if;

        distX := this.entity.nextPath.x - this.entity.x;
        distY := this.entity.nextPath.y - this.entity.y;
        flightTime := sqrt(distX*distX + distY*distY) / this.liftSpeed();
        if flightTime > 0 then
            this.entity.vx := distX / flightTime;
            this.entity.vy := distY / flightTime;
        else
            this.entity.vx := 0;
            this.entity.vy := 0;
        end if;

        if this.entity.vx = 0 and this.entity.vy = 0 then
            // already at the point
            this.entity.nextPath.Send("LiftArrived", {lift: this.entity});
        else
            // calculate how long it will take to reach the next path point.
            // set up a timer to announce the lift's arrival and clamp it to
            // the next path location exactly. prevents drifting.
            this.SetTimer("Arrive", flightTime * 1000);
        end if;
    end function

    member Arrive()
        this.entity.x := this.entity.nextPath.x;
        this.entity.y := this.entity.nextPath.y;
        this.entity.vx := 0;
        this.entity.vy := 0;
        this.entity.nextPath.Send("LiftArrived", {lift: this.entity});
    end function
}

}
