// A specific-use script used by the LiftPath entity. Each LiftPath entity is
// connected to the next LiftPath point in the path. When it receives a
// "LiftArrived" message, it directs the lift to the next path point with a
// "LiftGoto" message. If the LiftPath is locked or has a pause, it will wait
// to send the goto message until the lift is allowed to proceed.
//
{

script: {
	member OnConnect(args : map)
		if args.eid.template = "LiftPath" then
			// the next path point is stored in the entity's attributes
			// so the path doesn't have to be reconnected if it is respawned
			// during a world file version upgrade.
			this.entity.nextPath := args.eid;
			this.entity.connections := [this.entity.nextPath];      // for the editor's benefit
		end if;
	end function

	member OnDisconnect(args : map)
		if args.eid = this.entity.nextPath then
			this.entity.nextPath := null;
			this.entity.connections -= [args.eid];
		end if;
	end function

	member OnLiftArrived(args : map)
		this.waitingLift := args.lift;
		this.forwardLift();
	end function

	member OnSwitched(args : map)
		this.entity.locked := !args.on;
		this.forwardLift();
	end function

	//
	// Fowards the waiting lift if the path is not locked.
	//
	member forwardLift()
		if this.waitingLift != null and !this.entity.locked then
			this.waitingLift.Send("LiftGoto", {path: this.entity.nextPath});
			this.waitingLift := null;
		end if;
	end function

	// this is only set when a lift has arrived and the path is locked
	waitingLift: null
}
 
}