uniform sampler2D al_tex;
uniform bool      al_use_tex;
uniform vec2      light_pos;
uniform float     light_radius;

varying vec4      varying_color;
varying vec2      varying_texcoord;

void main()
{
    if (al_use_tex)
    {
        gl_FragColor = varying_color * texture2D(al_tex, varying_texcoord);
    }
    else
    {
        gl_FragColor = varying_color;
    }

    // when drawing a texture, discard all transparent fragments, to avoid
    // writing to the depth buffer.
    if (gl_FragColor.w == 0.0)
    {
        discard;
    }

    // light position is in the center of the area being drawn
    vec2 light_pos = vec2(light_radius, light_radius);

    // distance of the fragment being drawn from the source of the light
    float dist = distance(varying_texcoord, light_pos);

    // light brightness (1.0 = full bright)
    float brightness = clamp(1.0 - dist*dist/(light_radius*light_radius), 0.0, 1.0);
    brightness *= brightness;

    gl_FragColor *= brightness;
}
