// PARTICLE EMITTER PROPERTIES
// ===========================
//
// Property     Description                         Type    Default     Units
// --------     -----------                         ----    -------     -----
// lifespan     Lifespan of the particle            number  -           milliseconds
// texture      Texture to be drawn                 map     -           {lib: "<tileLib>", frame: "<filename>"}
// additive     Drawn with additive blending?       boolean True
// angle        Angle of movement                   number  0           degrees
// speed        Initial speed of the particle       number  0           pixels/sec
// gravity      Gravitational acceleration          number  0           pixels/sec^2
// radial       Radial acceleration                 number  0           pixels/sec^2
// tangent      Tangential acceleration             number  0           pixels/sec^2
// vTangent     Tangential velocity                 number  0           pixels/sec
// rot          Angle of rotation                   number  0           degrees
// vRot         Rotational velocity                 number  0           degrees/sec
// size1        Initial width of particle           number  <texture>   pixels
// size2        Final width of particle             number  <size1>     pixels
// color1       Initial color+opacity of particle   string  "#FFFFFFFF" "#RRGGBBAA"
// color2       Final color+opacity of particle     string  "#FFFFFFFF" "#RRGGBBAA"
// light1       Initial emissive light brightness   number  0           0.0-1.0
// light2       Final emissive light brightness     number  0           0.0-1.0 (<0.0 = light1)
// ---
// lifespanVar  Variation in particle lifespans     number  0           milliseconds
// xVar         Variation in x origin of particle   number  0           pixels
// yVar         Variation in y origin of particle   number  0           pixels
// angleVar     Variation in movement angle         number  0           degrees
// speedVar     Variation in initial speed          number  0           pixels/sec
// radialVar    Variation in radial acceleration    number  0           pixels/sec^2
// tangentVar   Variation in tangent acceleration   number  0           pixels/sec^2
// vTangentVar  Variation in tangential velocity    number  0           pixels/sec
// rotVar       Variation in initial rotation       number  0           degrees
// vRotVar      Variation in rotational velocity    number  0           degrees/sec
// size1Var     Variation in initial size           number  0           pixels
// size2Var     Variation in final size             number  0           pixels
// color1Var    Variation in initial color          string  0           "#RRGGBBAA"
// color2Var    Variation in final color            string  0           "#RRGGBBAA"
// light1Var    Variation in initial brightness     number  0           0.0-1.0
// light2Var    Variation in final size             number  0           pixels

[

{Include: "particles-items.sv"}

{Emitter: "StunnerBlast1",
    Properties: {
        lifespan: 210
        texture: "particles:phaze-blast1"
        additive: false
    }
}

// Debris thrown out around the stunner blast
{Emitter: "StunnerBlast2",
    Properties: {
        lifespan: 250, lifespanVar: 200
        angleVar: 360
        speed: 96, speedVar: 64
        size1: 2.5, size1Var: 2
        color1: "#00ff00", color1Var: "#ff00ff"
        color2: "#00ff0000"
        texture: "particles:pixel"
        additive: false
        light1: 0.9, light1Var: 0.2
        light2: 0.3, light2Var: 0.2
    }
}

]