// A component used exclusively by the Socket entities that sends a "Switched"
// message to its connections when it's activated on touch and the player has
// the required key.
//
// Variable     Type       Description
// --------     ----       -----------
// key          string     The name of the item required by the socket.
// onFrame      string     The frame of the socket after it's switched on.
// sound        string     Sound to play when activated (default="use_gem")
//
{

script: {
	member OnConnect(args : map)
		if !(args.eid in this.entity.connections) then
			this.entity.connections &= [args.eid];
		end if;
	end function

	member OnDisconnect(args : map)
		this.entity.connections -= [args.eid];
	end function

	member OnActivateOnTouch(args : map)
		if !this.entity.switchOn and game[this.key] > 0 then
			args.eid.Send("Switching");
			this.entity.switchOn := true;
			game[this.key] -= 1;
			this.entity.frame := this.onFrame;
			PlaySound(this.sound);
			for i is 1 to length(this.entity.connections) loop
				this.entity.connections[i].Send("Switched", {on: true});
			end loop;
		end if;
	end function

	key    : null           // Required
	onFrame: null           // Required
	sound  : "use_gem"
}

}
